Properties Methods Events Config Options Direct Link

# Class Ext.ensible.cal.StatusProxy

Package: | Ext.ensible.cal
Defined In: | StatusProxy.js
Class: | StatusProxy
Extends: | Object

A specialized drag proxy that supports a drop status icon, Ext.Layer styles and auto-repair. It also contains a calendar-specific drag status message containing details about the dragged event's target drop date range. This is the default drag proxy used by all calendar views.

## Config Options

Config Options | Defined By
--- | ---
| addEventCls : String The CSS class to apply to the status element when drop is not allowed (defaults to 'ext-cal-dd-add'). | StatusProxy
| moveEventCls : String The CSS class to apply to the status element when an event is being dragged (defaults to 'ext-cal-dd-move'). | StatusProxy

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.